@@ -9,7 +9,7 @@ async def build_embed(parent, ctx: commands.Context, **kwargs):
     Helper to determine whether or not an embed should be used
     """
 
-    await WidgitEmbed(parent).build(ctx, **kwargs)
+    return await WidgitEmbed(parent).build(ctx, **kwargs)
 
 
 class WidgitEmbed:
